VMTraceClient class

A client for tracing WebSocket frames via the Dart VM Service.

Constructors

VMTraceClient(Uri vmServiceUri)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vmServiceUri Uri
final

Methods

dispose() Future<void>
Disposes of the VM service connection.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startTracing({FrameCallback? onFrame}) Future<void>
Starts tracing WebSocket frames.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited